paidiverpy.models.client_params
===============================

.. py:module:: paidiverpy.models.client_params

.. autoapi-nested-parse::

   Client parameters module.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.models.client_params.ClientParams


Module Contents
---------------

.. py:class:: ClientParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Client parameters class.

   This class is used to define the client parameters for Dask parallel processing.















   ..
       !! processed by numpydoc !!

